Index: fetch_configs/infra_internal.py |
diff --git a/recipes/infra_internal.py b/fetch_configs/infra_internal.py |
similarity index 86% |
rename from recipes/infra_internal.py |
rename to fetch_configs/infra_internal.py |
index ad6afb9c34271cfadf0a2c87314beeaafa453e90..5643fc1114e9f4c9ae20566beb3f6cf1cdb05725 100644 |
--- a/recipes/infra_internal.py |
+++ b/fetch_configs/infra_internal.py |
@@ -4,13 +4,13 @@ |
import sys |
-import recipe_util # pylint: disable=F0401 |
+import config_util # pylint: disable=F0401 |
# This class doesn't need an __init__ method, so we disable the warning |
# pylint: disable=W0232 |
-class InfraInternal(recipe_util.Recipe): |
- """Basic Recipe class for the whole set of Infrastructure repositories.""" |
+class InfraInternal(config_util.Config): |
+ """Basic Config class for the whole set of Infrastructure repositories.""" |
@staticmethod |
def fetch_spec(_props): |